@@ -2,7 +2,7 @@
 
 /*
  * File "mmc_format.c" is part of the UDFclient toolkit.
- * File $Id: mmc_format.c,v 1.14 2015/08/05 18:26:29 reinoud Exp $ $Name:  $
+ * File $Id: mmc_format.c,v 1.15 2016/04/25 21:01:39 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -515,11 +515,8 @@ uscsi_format_cdrw_mode7(struct uscsi_dev *dev, uint32_t blocks)
 {
 	scsicmd cmd;
 	struct uscsi_sense sense;
-	uint32_t param;
 	uint8_t  buffer[16];
-	int cnt, error;
-
-	param = cnt = 0;
+	int error;
 
 	if (blocks % 32) {
 		blocks -= blocks % 32;
