@@ -38,7 +38,7 @@ uint16_t udf_cksum(uint8_t *s, int n);
 uint16_t udf_unicode_cksum(uint16_t *s, int n);
 uint16_t udf_ea_cksum(uint8_t *);
 int      UDFTransName(unicode_t *, unicode_t *, int);
-int      UnicodeLength(unicode_t *string);
+int      UnicodeLength(unicode_t *string, int maxlength);
 
 
 #endif /* _OSTA_H_ */
