@@ -2,7 +2,7 @@
 
 /*
  * File "udf_verbose.c" is part of the UDFclient toolkit.
- * File $Id: udf_verbose.c,v 1.117 2015/08/05 18:26:31 reinoud Exp $ $Name:  $
+ * File $Id: udf_verbose.c,v 1.118 2016/04/25 21:01:40 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -575,7 +575,7 @@ void udf_dump_icb_tag(struct icb_tag *icb_tag) {
 	uint32_t flags, strat_param16;
 
 	flags = udf_rw16(icb_tag->flags);
-	strat_param16 = udf_rw16(* (uint16_t *) icb_tag->strat_param);
+	strat_param16 = udf_rw16(icb_tag->strat_param16);
 	printf("\t\tICB Prior direct entries recorded (excl.)   %d\n", udf_rw32(icb_tag->prev_num_dirs));
 	printf("\t\tICB Strategy type                           %d\n", udf_rw16(icb_tag->strat_type));
 	printf("\t\tICB Strategy type flags                     %d %d\n", icb_tag->strat_param[0], icb_tag->strat_param[1]);
@@ -733,7 +733,7 @@ void udf_dump_extattrseq(uint8_t *start, uint32_t offset, uint32_t impl_offset,
 			case  2048 :	/* [4/48.10.9] implementation use extended attributes */
 				impl_extattr = (struct impl_extattr_entry *) pos;
 				iu_l = udf_rw32(impl_extattr->iu_l);
-				chksum = udf_rw16(*((uint16_t *) impl_extattr->data));
+				chksum = udf_rw16(impl_extattr->data16);
 
 				printf("\t\t\tImplementation use extended attribute\n");
 				if (chksum != udf_ea_cksum(pos))
@@ -863,13 +863,11 @@ void udf_dump_file_entry(struct file_entry *fe) {
 	uint8_t		*pos;
 	uint32_t	 length;
 	uint8_t		 addr_type;
-	uint32_t	 entries;
-	uint16_t	 strategy, strat_param16;
 
 	/* direct_entries = udf_rw32(fe->icbtag.prev_num_dirs); */
-	strat_param16  = udf_rw16(* (uint16_t *) (fe->icbtag.strat_param));
-	entries        = udf_rw16(fe->icbtag.max_num_entries);
-	strategy       = udf_rw16(fe->icbtag.strat_type);
+	//strat_param16  = udf_rw16(* (uint16_t *) (fe->icbtag.strat_param));
+	//entries        = udf_rw16(fe->icbtag.max_num_entries);
+	//strategy       = udf_rw16(fe->icbtag.strat_type);
 	addr_type      = udf_rw16(fe->icbtag.flags) & UDF_ICB_TAG_FLAGS_ALLOC_MASK;
 
 	printf("\tFile entry\n");
@@ -913,13 +911,11 @@ void udf_dump_extfile_entry(struct extfile_entry *efe) {
 	uint8_t		*pos;
 	uint32_t	 length;
 	uint8_t		 addr_type;
-	uint32_t	 entries;
-	uint16_t	 strategy, strat_param16;
 
 	/* direct_entries = udf_rw32(efe->icbtag.prev_num_dirs); */
-	strat_param16  = udf_rw16(* (uint16_t *) (efe->icbtag.strat_param));
-	entries        = udf_rw16(efe->icbtag.max_num_entries);
-	strategy       = udf_rw16(efe->icbtag.strat_type);
+	//strat_param16  = udf_rw16(* (uint16_t *) (efe->icbtag.strat_param));
+	//entries        = udf_rw16(efe->icbtag.max_num_entries);
+	//strategy       = udf_rw16(efe->icbtag.strat_type);
 	addr_type      = udf_rw16(efe->icbtag.flags) & UDF_ICB_TAG_FLAGS_ALLOC_MASK;
 
 	printf("\tExtended file entry\n");
