@@ -2,7 +2,7 @@
 
 /*
  * File "udfclient.c" is part of the UDFclient toolkit.
- * File $Id: udfclient.c,v 1.102 2015/08/05 18:26:31 reinoud Exp $ $Name:  $
+ * File $Id: udfclient.c,v 1.104 2016/04/25 21:28:00 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -390,12 +390,14 @@ void udfclient_ls(int args, char *arg1) {
 
 void udfclient_pwd(int args) {
 	char pwd[1024];
+	char *res;
 
 	if (args) {
 		printf("Syntax: pwd\n");
 		return;
 	}
-	getcwd(pwd, 1024);
+	res = getcwd(pwd, 1024);
+	assert(res);
 	printf("UDF working directory is     %s\n", curdir.name);
 	printf("Current FS working directory %s\n", pwd);
 }
@@ -414,7 +416,7 @@ void udfclient_free(int args) {
 	struct logvol_desc *lvd;
 	uint64_t part_size, unalloc_space, freed_space;
 	uint64_t total_space, free_space, await_alloc_space;
-	uint32_t sector_size, lb_size;
+	uint32_t lb_size;
 	int part_num;
 
 	if (args) {
@@ -428,7 +430,7 @@ void udfclient_free(int args) {
 	}
 
 	lb_size = udf_log_vol->lb_size;
-	sector_size = udf_log_vol->sector_size;
+	// sector_size = udf_log_vol->sector_size;
 
 	lvd = udf_log_vol->log_vol;
 	udf_dump_id("Logical volume ", 128, lvd->logvol_id, &lvd->desc_charset);
@@ -525,6 +527,7 @@ void udfclient_cd(int args, char *arg1) {
 
 void udfclient_lcd(int args, char *arg1) {
 	char pwd[1024];
+	char *res;
 
 	if (args > 1) {
 		printf("Syntax: lcd [dir]\n");
@@ -538,7 +541,8 @@ void udfclient_lcd(int args, char *arg1) {
 		fprintf(stderr, "While trying to go to %s :", arg1);
 		perror("");
 	}
-	getcwd(pwd, 1024);
+	res = getcwd(pwd, 1024);
+	assert(res);
 	printf("Changing local directory to %s\n", pwd);
 }
 
@@ -571,7 +575,7 @@ int udfclient_get_file(struct udf_node *udf_node, char *fullsrcname, char *fulld
 	uint64_t	 file_length;
 	uint64_t 	 start, now, then, eta;
 	uint64_t	 cur_speed, avg_speed, data_transfered;
-	uint64_t	 file_block_size, file_transfer_size;
+	uint64_t	 file_block_size, file_transfer_size, written;
 	uint8_t		*file_block;
 	char		 cur_txt[32], avg_txt[32], eta_txt[32];
 	int		 fileh, len;
@@ -648,7 +652,8 @@ int udfclient_get_file(struct udf_node *udf_node, char *fullsrcname, char *fulld
 				break;
 			}
 
-			write(fileh, file_block, file_transfer_size);
+			written = write(fileh, file_block, file_transfer_size);
+			assert(written == file_transfer_size);
 
 			if ((getmtime() - now > 1000000) || ((uint64_t) file_uio.uio_offset >= file_length)) {
 				if (strlen(fulldstname) < 45) {
@@ -1547,7 +1552,7 @@ void udfclient_interact(void) {
 		clearerr(stdin);
 
 		*line = 0;
-		fgets(line, 4096, stdin);
+		(void) fgets(line, 4096, stdin);
 
 		if ((*line == 0) && feof(stdin)) {
 			printf("quit\n");
